@@ -22,10 +22,10 @@ class VPS(_defaults_.Defaults):
 	):	
 
 		# docs.
-		Docs.__init__(self,
-			initialized=True,
-			module="website.vps", 
-			notes=[], )
+		DOCS = {
+			"module":"website.vps", 
+			"initialized":True,
+			"description":[], }
 
 		# defaults.
 		_defaults_.Defaults.__init__(self, traceback="w3bsite.Website.vps",)
